.. Musher documentation master file, created by
   sphinx-quickstart on Sun Nov 15 14:49:53 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Musher's documentation!
==================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
